<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="226"/>
        <source>Drop Error</source>
        <translation>Ошибка при перетаскивании</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="227"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Файл/URL-адрес &apos;%1&apos; сейчас не может быть встроен в быстрый запуск</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="333"/>
        <source>Drop application
icons here</source>
        <translation>Перетащите значки
приложений сюда</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Сдвинуть влево</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Сдвинуть вправо</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="64"/>
        <source>Remove from quicklaunch</source>
        <translation>Удалить из быстрого запуска</translation>
    </message>
</context>
</TS>
